==> flutter_mylibrary-0.2.17.tar.gz: lib/utils/win_media.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/flutter_mylibrary.dart';
import 'package:flutter_mylibrary/utils/flutter_size_fit.dart';

double winWidth(BuildContext context) {
  return MediaQuery.of(context).size.width;
}

double winHeight(BuildContext context) {
  return MediaQuery.of(context).size.height;
}

double winTop(BuildContext context) {
  return MediaQuery.of(context).padding.top;
}

double winBottom(BuildContext context) {
  return MediaQuery.of(context).padding.bottom;
}

double winLeft(BuildContext context) {
  return MediaQuery.of(context).padding.left;
}

double winRight(BuildContext context) {
  return MediaQuery.of(context).padding.right;
}

double winKeyHeight(BuildContext context) {
  return MediaQuery.of(context).viewInsets.bottom;
}

double statusBarHeight(BuildContext context) {
  return MediaQueryData.fromWindow(window).padding.top;
}

double navigationBarHeight(BuildContext context) {
  return kToolbarHeight;
}

double topBarHeight(BuildContext context) {
  return kToolbarHeight + MediaQueryData.fromWindow(window).padding.top;
}


double getSp(double sp){
  return FlutterSizeFit.setRpx(sp);
}

double getHeight(double height){
  return FlutterSizeFit.setRpx(height);
}

double getWidth(double width){
  return FlutterSizeFit.setRpx(width);
}

EdgeInsets getEdgeInsetsAll(double value){
  return EdgeInsets.symmetric(vertical: getHeight(value), horizontal: getWidth(value));
}

EdgeInsets getEdgeInsetsSymmetric({double vertical = 0, double horizontal = 0}){
  return EdgeInsets.symmetric(vertical: getHeight(vertical), horizontal: getWidth(horizontal));
}


EdgeInsets getEdgeInsetsOnly({double left = 0, double right = 0, double top = 0, double bottom = 0}){
  return EdgeInsets.only(left: getWidth(left), right: getWidth(right), top: getHeight(top), bottom: getHeight(bottom));
}

==> flutter_mylibrary-0.2.20.tar.gz: lib/utils/win_media.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mylibrary/flutter_mylibrary.dart';
import 'package:flutter_mylibrary/utils/flutter_size_fit.dart';

double winWidth(BuildContext context) {
  return MediaQuery.of(context).size.width;
}

double winHeight(BuildContext context) {
  return MediaQuery.of(context).size.height;
}

double winTop(BuildContext context) {
  return MediaQuery.of(context).padding.top;
}

double winBottom(BuildContext context) {
  return MediaQuery.of(context).padding.bottom;
}

double winLeft(BuildContext context) {
  return MediaQuery.of(context).padding.left;
}

double winRight(BuildContext context) {
  return MediaQuery.of(context).padding.right;
}

double winKeyHeight(BuildContext context) {
  return MediaQuery.of(context).viewInsets.bottom;
}

double statusBarHeight(BuildContext context) {
  return MediaQueryData.fromWindow(window).padding.top;
}

double navigationBarHeight(BuildContext context) {
  return kToolbarHeight;
}

double topBarHeight(BuildContext context) {
  return kToolbarHeight + MediaQueryData.fromWindow(window).padding.top;
}


double getSp(double sp){
  return FlutterSizeFit.setPx(sp);
}

double getHeight(double height){
  return FlutterSizeFit.setPx(height);
}

double getWidth(double width){
  return FlutterSizeFit.setPx(width);
}

EdgeInsets getEdgeInsetsAll(double value){
  return EdgeInsets.symmetric(vertical: getHeight(value), horizontal: getWidth(value));
}

EdgeInsets getEdgeInsetsSymmetric({double vertical = 0, double horizontal = 0}){
  return EdgeInsets.symmetric(vertical: getHeight(vertical), horizontal: getWidth(horizontal));
}


EdgeInsets getEdgeInsetsOnly({double left = 0, double right = 0, double top = 0, double bottom = 0}){
  return EdgeInsets.only(left: getWidth(left), right: getWidth(right), top: getHeight(top), bottom: getHeight(bottom));
}
